<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ============================= //
	// lang_admin.php - Français 1.3 //
	// ============================= //

	// Français formel (Vous) //
	// This language file was translated by Jürgen Schäfer, 2010; ==> http://www.minetoshsoft.com // 
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// general values
	$lang['no'] = "Non";
	$lang['yes'] = "Oui";
	$lang['asc'] = "Ascendant";
	$lang['desc'] = "Descendant";
	$lang['save'] = "Enregistrer";
	$lang['administrator'] = "Administrateur";
	$lang['moderator'] = "Modérateur";

	// login.php
	$lang['title'] = "MGB {MGB_VERSION} - Administration";
	$lang['login_username'] = "Nom d’utilisateur:";
	$lang['login_password'] = "Mot de passe:";
	$lang['login_lostpassword'] = "J’ai oublié mon mot de passe";
	$lang['login'] = "Connexion";
	$lang['logout'] = "Quitter";
	$lang['login_ok'] = "Bienvenue <b>{SESSION_USERNAME}</b>.";
	$lang['logged_in'] = "Vous êtes connecté en tant que <b>{SESSION_USERNAME}</b>.";
	$lang['logged_out'] = "Entrez votre nom d'utilisateur et votre mot de passe pour vous connecter, s’il vous plaît.";
	$lang['please_wait'] = "Votre connexion a été effectuée avec succès.<br>Attendez un moment, s'il vous plaît…";

	// errormessages
	$lang['errormessage1'] = "Remplissez tous les champs, s'il vous plaît!";
	$lang['errormessage2'] = "Cette combinaison nom d'utilisateur / mot de passe n'existe pas.";
	$lang['errormessage3'] = "Votre compte a été désactivé par un administrateur.";
	$lang['errormessage4'] = "Vous n’avez pas accès à cette page.";
	$lang['errormessage5'] = "Le mot de passe n’est pas correct.";
	$lang['errormessage6'] = "Les nouveaux mots de passe ne sont pas identiques.";
	$lang['errormessage7'] = "Vous n’avez pas donné d'adresse E-mail ou elle n’est pas valide.";
	$lang['errormessage8'] = "Vous ne pouvez pas désactiver votre propre statut d’administrateur, ou désactiver ou supprimer votre propre compte d’utilisateur.";
	$lang['errormessage9'] = "Vous avez été inactif trop longtemps. Vous êtes, donc, déconnecté automatiquement.";
	$lang['errormessage10'] = "Lors de la dernière visite, vous ne vous êtes pas déconnecté correctement. Le système l’a fait pour vous.<br><br>Pour votre propre sécurité, utilisez toujours le bouton ''Quitter'' pour vous déconnecter du système, sil vous plaît. Merci.";
	$lang['errormessage11'] = "Ce nom d’utilisateur ou cette adresse E-Mail sont déjà utilisés.";
	$lang['errormessage12'] = "Cette clé est invalide ou a déjà expiré.";
	$lang['errormessage13'] = "Il a déjà été demandé un nouveau mot de passe pour ce compte d’utilisateur.<br>Il n’est pas possible de demander un autre mot de passe avant l’activation ou l’expiration du nouveau mot de passe.";
	$lang['errormessage14'] = "L’e-mail n'a pas pu être envoyé. Il peut y avoir un problème avec le serveur de messagerie.";
	$lang['errormessage15'] = "La version n'a pas pu être déterminée, parce que la fonction <a href=\"http://php.net/manual/de/function.fopen.php\">fopen()</a> est désactivée sur votre serveur.<br>Contactez éventuellement votre hébergeur Web.<br><br>En attendant, vous trouverez la version la plus actuelle sur http://www.m-gb.org/.";

	// general strings
	$lang['back_to_mainpage'] = "Retour à la page principale";
	$lang['back'] = "Retour";
	$lang['go'] = "Go!";
	$lang['entry'] = "Entrée";
	$lang['entries'] = "Entrées";
	$lang['no_entries'] = "Aucune entrée";
	$lang['no_deactivated_entries'] = "Aucune entrée désactivée";
	$lang['no_activated_entries'] = "Aucune entrée activée";
	$lang['no_spam_entries'] = "No spam entries available.";
	$lang['entries_on_pages'] = "Entrées sur {PAGES} pages";
	$lang['page_first'] = "Aller à la première page";
	$lang['page_first_symbol'] = "&laquo;";
	$lang['page_forwards'] = "Aller à la page suivante";
	$lang['page_forwards_symbol'] = "&rsaquo;";
	$lang['page_last'] = "Aller à la dernière page";
	$lang['page_last_symbol'] = "&raquo;";
	$lang['page_backwards'] = "Aller à la page précédente";
	$lang['page_backwards_symbol'] = "&lsaquo;";
	$lang['captcha_method_code'] = "Code de sécurité";
	$lang['captcha_method_math'] = "Mathématique";
	$lang['activate_entry'] = "Activer cette entrée";
	$lang['deactivate_entry'] = "Désactiver cette entrée";
	$lang['delete_entry'] = "Supprimer cette entrée";
	$lang['mark_as_spam'] = "Marquer comme Spam";
	$lang['nospam_entry'] = "Marquer l’entrée comme 'pas un Spam' et activer cette entrée";
	$lang['nospam_deactivate_entry'] = "Marquer l’entrée comme 'pas un Spam', mais la laisser désactivée";
	$lang['active'] = "Cette entrée est activée dans le livre d’hôtes.";
	$lang['inactive'] = "Cette entrée n’est pas activée dans le livre d’hôtes.";
	$lang['edit_entry'] = "Éditer cette entrée";
	$lang['do_nothing'] = "Ne rien faire...";
	$lang['delete_whole_spam'] = "Effacer toutes les entrées Spam";
	$lang['mark_all_no_spam_deactivate'] = "Marquer toutes les entrées comme 'pas un Spam' et les activer";
	$lang['mark_all_no_spam_activate'] = "Marquer toutes les entrées comme 'pas un Spam', mais les laisser désactivées";
	$lang['mark_all_as_spam'] = "Marquer toutes les entrées comme Spam";
	$lang['activate_all_entries'] = "Activer toutes les entrées";
	$lang['deactivate_all_entries'] = "Désactiver toutes les entrées";
	$lang['delete_all_entries'] = "Effacer toutes les entrées";

	$lang['sendmail_user_notification_title'] = "Votre entrée sur {DOMAIN} a été activée.";
	$lang['sendmail_user_comment_title'] = "Sur votre entrée sur {DOMAIN} un commentaire a été déposé.";
	$lang['sendmail_adduser_title'] = "Vos données d’utilisateur sur {DOMAIN}";
	$lang['sendmail_adduser_text'] = "Vous êtes enregistré avec succès à {DOMAIN} par un administrateur. Voici vos données d'utilisateur:<br /><br />Nom d'utilisateur: {ADDUSER_NAME}<br />Mot de passe: {ADDUSER_PASSWORD}<br /><br />Vous pouvez vous connecter ici: {ADDUSER_URL}";
	$lang['sendmail_admin_text'] = "{NAME} a déposé une nouvelle entrée dans le livre d’hôtes.<br /><br />Date: {DATE}<br />Heure: {TIME}<br /><br />---<br />{MESSAGE}<br />---";
	$lang['sendmail_user_text'] = "Bonjour {NAME},<br /><br />Merci pour votre entrée dans mon livre d’hôtes. Après examen, elle sera activée dès que possible.";
	$lang['sendmail_user_notification_text'] = "Bonjour {NAME},<br /><br />Votre entrée sur {DOMAIN} vient d’être activée. Vous pouvez la regarder ici: {URL_TO_GB}";
	$lang['sendmail_comment_text'] = "Bonjour {NAME},<br /><br />Sur votre entrée<br /><br />---<br />{MESSAGE}<br />---<br /><br />un commentaire vient d’être déposé. Vous pouvez le regarder ici: {URL_TO_GB}";
	$lang['sendmail_contactmail_text'] = "Vous avez reçu un e-mail de {NAME} par le livre d’hôtes de {DOMAIN}. Voici le message:<br /><br />---<br />{MESSAGE}<br />---<br /><br />Date: {DATE}<br />Heure: {TIME}";
	$lang['sendmail_new_password_title'] = "Nouveau mot de passe: Confirmation";
	$lang['sendmail_new_password_text'] = "Bonjour {NAME},<br /><br />Pour votre compte d’utilisateur, un nouveau mot de passe a été généré. Pour le confirmer, cliquez dans les prochaines 24 heures sur le lien ci-dessous. L’ancien mot de passe reste actif, jusqu'à ce que le nouveau mot de passe ait été activé. <br /><br />Le nouveau mot de passe expire, si vous ne cliquez pas sur le lien ci-dessous dans les prochaines 24 heures.<br /><br />{NEW_PASSWORD_LINK}";
	$lang['sendmail_new_password_created_title'] = "Le nouveau mot de passe a été activé";
	$lang['sendmail_new_password_created_text'] = "Bonjour {NAME},<br /><br />Vous avez confirmé votre nouveau mot de passe avec succès. S'il vous plaît, trouvez ci-joint les nouvelles données d’accès.<br /><br />Nom d’utilisateur: {NAME}<br />Mot de passe: {NEW_PASSWORD}";	

	// navigation
	$lang['settings'] = "Configuration";
	$lang['activate'] = "Activer entrée";
	$lang['deactivate'] = "Désactiver entrée";
	$lang['delete'] = "Supprimer entrée";
	$lang['edit'] = "Éditer entrée";
	$lang['spam'] = "Entrées classées comme Spam";
	$lang['users'] = "Administration d’utilisateurs";
	$lang['stats'] = "Statistiques";
	$lang['license'] = "Licence";
	$lang['forum'] = "Forum";
	$lang['bugreport'] = "Signaler une erreur";
	$lang['version'] = "Version";
	$lang['manual'] = "Documentation";
	$lang['paypal'] = "Si vous trouvez le MGB utile, nous vous invitons à faire un don pour soutenir son développement.";

	// settings.php
	$lang['edit_caption_general'] = "Paramètres généraux";
	$lang['edit_caption_look'] = "Apparence";
	$lang['edit_caption_gravatars'] = "Soutien Gravatar";
	$lang['edit_caption_security'] = "Sécurité";
	$lang['edit_caption_email'] = "E-Mail";
	$lang['edit_save_message'] = "Les préférences ont été enregistrées avec succès.";
	$lang['edit_title'] = "Titre:";
	$lang['edit_h_author'] = "Auteur:";
	$lang['edit_h_domain'] = "Domaine:";
	$lang['edit_gb_path'] = "Chemin d'accès vers le livre d’hôtes:";
	$lang['edit_h_keywords'] = "Mots-clés:";
	$lang['edit_h_description'] = "Description:";
	$lang['edit_admin_name'] = "Nom de l’administrateur:";
	$lang['edit_admin_email'] = "E-Mail de l’administrateur:";
	$lang['edit_admin_gbemail'] = "E-Mail du livre d’hôtes:";
	$lang['edit_sendmail_admin'] = "E-Mail de notification:";
	$lang['edit_sendmail_admin_text'] = "Texte pour e-Mail de notification:";
	$lang['edit_sendmail_user'] = "E-Mail de remerciement à l'utilisateur:";
	$lang['edit_sendmail_user_text'] = "Texte d’e-Mail de remerciement:";
	$lang['edit_sendmail_user_notification_text'] = "Texte pour e-Mail d’activation:";
	$lang['edit_sendmail_comment_text'] = "Texte de notification de commentaire:";
	$lang['edit_sendmail_contactmail_text'] = "Texte e-Mail par le livre d’hôtes:";
	$lang['edit_template_path'] = "Modèle:";
	$lang['edit_template_style_path'] = "Style du modèle:";
	$lang['edit_iconset_path'] = "Jeu de dessins:";
	$lang['edit_language_path'] = "Fichier de langue:";
	$lang['edit_badwords'] = "Mots interdits:";
	$lang['edit_bbcode'] = "BBcodes:";
	$lang['edit_smileys'] = "Smileys:";
	$lang['edit_captcha'] = "Code de sécurité:";
	$lang['edit_captcha_method'] = "Type de Captcha:";
	$lang['edit_akismet_plugin'] = "Akismet-Plugin:";
	$lang['edit_akismet_api'] = "Akismet API Key (obligatoire):";
	$lang['edit_akismet_mark_as_spam'] = "Indication Spam:";
	$lang['edit_time_lock'] = "Blocage d'envoi:";
	$lang['edit_time_lock_value'] = "Temps minimal pour le blocage d'envoi:";
	$lang['edit_time_lock_maxtime'] = "Temps maximal pour le blocage d'envoi:";
	$lang['edit_user_notification'] = "Notification à l’utilisateur:";
	$lang['edit_user_show_email'] = "E-Mail d’utilisateur dans le livre d’hôtes:";
	$lang['edit_session_timeout'] = "Temps max. d’une session:";
	$lang['edit_moderated'] = "Livre d’hôtes modéré:";
	$lang['edit_entries_per_page'] = "Entrées par page:";
	$lang['edit_entries_order'] = "Séquence de numérotation:";
	$lang['edit_spam_protection'] = "Protection contre les spams:";
	$lang['edit_ipblocker'] = "Barrière IP:";
	$lang['edit_wordwrap'] = "Saut de ligne:";
	$lang['edit_dateform'] = "Format de la date:";
	$lang['edit_gravatar_show'] = "Montrer les gravatars:";
	$lang['edit_gravatar_rating'] = "Classification des gravatars:";

	$lang['edit_expl_title'] = "Le titre sur le livre d’hôtes.";
	$lang['edit_expl_h_author'] = "Le nom de l’auteur du site.";
	$lang['edit_expl_h_domain'] = "Domaine sur lequel se trouve le livre d’hôtes <b>sans http://</b> au début, et <b>/</b> à la fin. (exemple.fr)";
	$lang['edit_expl_gb_path'] = "Le chemin d'accès relatif au domaine sur lequel se trouve le livre d’hôtes.";
	$lang['edit_expl_h_keywords'] = "Mots-clés, séparés par des virgules.";
	$lang['edit_expl_h_description'] = "Une brève description de la page.";
	$lang['edit_expl_admin_name'] = "Nom d’administrateur ou simplement ''Admin''.";
	$lang['edit_expl_admin_email'] = "À cette adresse sont envoyées les notifications concernant les nouvelles entrées.";
	$lang['edit_expl_admin_gbemail'] = "Utilisé comme adresse d'expédition des e-Mails.";
	$lang['edit_expl_sendmail_admin'] = "Si cette option est activée, l'administrateur va recevoir un e-Mail pour chaque nouvelle entrée.";
	$lang['edit_expl_sendmail_admin_text'] = "Ce texte sera envoyé à l'administrateur, si la notification par e-Mail est activée.<br><br>Champs disponibles: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
	$lang['edit_expl_sendmail_user'] = "Si cette option est activée, un e-Mail de remerciement sera envoyé à l’utilisateur pour son entrée dans le livre d’hôtes.";
	$lang['edit_expl_sendmail_user_text'] = "Ce texte sera envoyé à l’utilisateur, si l’option e-Mail de remerciement est activée.<br><br>Champs disponibles: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
	$lang['edit_expl_sendmail_user_notification_text'] = "Ce texte sera envoyé à l’utilisateur, dès que sa contribution aura été activée. La condition préalable est que l'utilisateur ait donné son accord.<br><br>Champs disponibles: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
	$lang['edit_expl_sendmail_comment_text'] = "Ce texte sera envoyé à l’utilisateur, si un administrateur ou un modérateur a déposé un commentaire concernant sa contribution. La condition préalable est que l'utilisateur ait donné son accord.<br><br>Champs disponibles: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
	$lang['edit_expl_sendmail_contactmail_text'] = "Ce texte sera envoyé aux utilisateurs qui reçoivent un e-mail par le livre d’hôtes, alors que la protection contre les spams est activée.<br><br>Champs disponibles: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
	$lang['edit_expl_template_path'] = "Le modèle à utiliser.";
	$lang['edit_expl_template_style_path'] = "Le style du modèle à utiliser. Ne peut être sélectionné qu’après que le modèle correspondant soit chargé.";
	$lang['edit_expl_iconset_path'] = "Le jeu de dessins à utiliser, qui fournit les icônes, les smileys et les arrière-plans pour le code de sécurité quelque soit le modèle.";
	$lang['edit_expl_language_path'] = "La langue à utiliser. En cas de problèmes avec les caractères spéciaux, il peut aider à changer de utf-8 en iso-8859-1 (ou vice-versa).";
	$lang['edit_expl_badwords'] = "Entrez les mots indésirables, séparés par des virgules, qui doivent être remplacés par des astérisques dans le livre d’hôtes. Laissez vide pour désactiver.";
	$lang['edit_expl_bbcode'] = "Permet une mise en forme du texte par l'utilisateur.";
	$lang['edit_expl_smileys'] = "Permet à l'utilisateur d'insérer des smileys.";
	$lang['edit_expl_captcha'] = "Si cette option est activée, on doit entrer un code de sécurité pour déposer une nouvelle entrée et envoyer un e-Mail à un utilisateur.";
	$lang['edit_expl_captcha_method'] = "Vous pouvez choisir entre un code de sécurité classique ou un code de sécurité mathématique, pour lequel l’utilisateur doit résoudre un calcul mathématique.";
	$lang['edit_expl_akismet_plugin'] = "Akismet est un service Anti-Spam externe, qui examine les nouvelles entrées. Si une entrée est classée comme Spam, elle est automatiquement marquée et désactivée."; /* Ich weiss jetzt nicht genau, wie sich Akismet im MGB verhält, bzw. welche Optionen man einstellen kann. Habe die neue Version des MGB noch nicht getestet. Wenn man wählen kann zwischen automatischer Blockierung der Spam Einträge, oder dass sie lediglich markiert und deaktiviert werden, dann bitte diesen String so stehen lassen. Wird der Spam immer automatisch blockiert, dann bitte den Teil nach "refusée" streichen. Wird dagegen der Spam immer markiert und deaktiviert, dann bitte den Teil "refusée ou" löschen.  	*/
	$lang['edit_expl_akismet_api'] = "Pour utiliser le service Akismet, l’Akismet-Plugin et une <a href='http://akismet.com/signup/#free' title='Akismet API Key'>clé API</a> sont nécessaires. Après avoir été enregistré, vous pouvez entrer la clé ici.";
	$lang['edit_expl_akismet_check_ok'] = "<span class='same_version'>Akismet est installé!</span>";
	$lang['edit_expl_akismet_check_fail'] = "<span class='old_version'>Akismet N’EST PAS installé!</span>";
	$lang['edit_expl_akismet_mark_as_spam'] = "Si cette option est activée, toutes les nouvelles entrées classées ‘positives’ par Akismet, seront marquées comme Spam et apparaîtront dans le panneau d’administration, où vous pourrez les contrôler vous même. Ensuite, vous pourrez décider quoi en faire.";
	$lang['edit_expl_time_lock'] = "Lorsque cette option est activée, un chronomètre fonctionne en arrière plan pour chaque nouvelle entrée dans le livre d'or. Si l'utilisateur envoie le formulaire avant que le chronomètre soit arrêté, il lui sera signalé qu'il est trop rapide ainsi que le nombre de secondes qu'il doit attendre pour envoyer le formulaire.";
	$lang['edit_expl_time_lock_value'] = "Le temps minimal en secondes pour le blocage d'envoi, que l'utilisateur doit attendre avant de pouvoir envoyer le formulaire.";
	$lang['edit_expl_time_lock_maxtime'] = "Le temps maximal en secondes pendant lequel l'utilisateur peut déposer une nouvelle entrée dans le livre d'or. Si ce temps est dépassé avant que l'entrée soit terminée, le blocage d'envoi reprend à zéro.";
	$lang['edit_expl_user_notification'] = "Permet à l'utilisateur de décider d'être informé par e-Mail lorsque son entrée a été activée.";
	$lang['edit_expl_user_show_email'] = "Permet à l'utilisateur de décider si son e-Mail est indiqué dans le livre d’hôtes ou non. S’il décoche cette case, personne sauf l’administrateur ne peut lui envoyer d’e-Mail.";
	$lang['edit_expl_session_timeout'] = "Un utilisateur est automatiquement déconnecté, s’il est inactif pendant cette période. Indication en <b>secondes</b>. La valeur doit être >= <b>60</b>.";
	$lang['edit_expl_moderated'] = "Si cette option est activée, les entrées doivent être déverrouillées avant qu'elles n’apparaissent dans le livre d’hôtes.";
	$lang['edit_expl_entries_per_page'] = "Indique le nombre d'entrées affichées sur une page. La valeur <b>ne doit pas être 0</b>.";
	$lang['edit_expl_entries_order'] = "Détermine l'ordre dans lequel les articles sont numérotés.";
	$lang['edit_expl_spam_protection'] = "Lorsque cette option est activée, en cliquant sur l'icône de e-Mail dans le message, un formulaire de contact s’ouvre, par lequel on peut alors envoyer un e-Mail. Les adresses e-Mail <b>ne sont pas</b> directement montrées!";
	$lang['edit_expl_ipblocker'] = "Empêche les entrées multiples dans une rangée.";
	$lang['edit_expl_wordwrap'] = "Indique le nombre de caractères au delà duquel un très long mot est retourné à la ligne. <b>0</b> pour désactiver cette option.";
	$lang['edit_expl_dateform'] = "Le format pour la date. La mise en forme de la date est possible à l'aide de la fonction php <a class='admin' href='http://www.php.net/manual/en/function.date.php' title='date()' target='_blank'>date()</a>.";
	$lang['edit_expl_gravatar_show'] = "Les gravatars (Global Recognized Avatars) sont de petites images qui apparaissent à côté de l'entrée de l'utilisateur. La condition de leur apparition est que l'utilisateur soit enregistré avec son adresse e-Mail chez le service <a class=\"admin\" href=\"http://site.gravatar.com/\" target=\"_blank\" title=\"Gravatar Service\">gravatar.com</a>.";
	$lang['edit_expl_gravatar_rating'] = "Détermine jusqu'à quel niveau les gravatars sont montrés.<br><br><b>G</b> = Pour tous les âges<br><b>PG</b> = Représentations de la violence légère, de personnes habillées de façon provocante et des gestes provocants<br><b>R</b> = Représentations de la violence intensive, Obscénités<br><b>X</b> = des images sexuellement offensantes";

// edit.php
	$lang['ID'] = "ID:";
	$lang['ip'] = "IP:";
	$lang['date'] = "Date:";
	$lang['time'] = "Heure:";
	$lang['name'] = "Nom:";
	$lang['city'] = "Ville:";
	$lang['email'] = "e-Mail:";
	$lang['icq'] = "ICQ:";
	$lang['aim'] = "AIM:";
	$lang['msn'] = "MSN:";
	$lang['hp'] = "Site Internet:";
	$lang['message'] = "Message:";
	$lang['user_notification'] = "Notification d’activation ou d’un commentaire:";
	$lang['user_show_email'] = "Activer e-Mail dans le livre d’hôtes:";
	$lang['comment'] = "Commentaire:";

// edit_user.php
	$lang['user_is_active'] = "Utilisateur est actif:";
	$lang['r_user_type'] = " Utilisateur est:";
	$lang['r_settings'] = "Changer configuration:";
	$lang['r_activate'] = "Activer les entrées:";
	$lang['r_deactivate'] = "Désactiver les entrées:";
	$lang['r_delete'] = "Supprimer les entrées:";
	$lang['r_edit'] = "Éditer les entrées:";
	$lang['r_spam'] = "Administration Spam:";
	$lang['old_password'] = "Votre mot de passe actuel:";
	$lang['new_password_1'] = "Mot de passe:";
	$lang['new_password_2'] = "Confirmer le mot de passe:";
	$lang['delete_user'] = "Confirmer:";
	$lang['edit_user_caption_rights'] = "Droits (pour les modérateurs seulement)";
	$lang['edit_user_caption_password'] = "Mot de passe de cet utilisateur:";
	$lang['edit_user_caption_delete_user'] = "Supprimer cet utilisateur";
	$lang['edit_user_caption_old_password'] = "Votre mot de passe actuel:";
	$lang['user_add'] = "Ajouter un utilisateur";
	$lang['user_edit'] = "Éditer utilisateur";
	$lang['edit_user_caption_send_account_data'] = "Envoyer les données";
	$lang['send_account_data'] = "Envoyer par e-Mail?";

// version.inc.php
	$lang['current_version'] = "Version installée:";
	$lang['stable_version'] = "Version stable la plus récente:";
	$lang['unstable_version'] = "Version instable la plus récente:";
	$lang['old_version'] = "Votre version est dépassée.<br>Une mise à jour est recommandée.<br><br><a href='http://www.m-gb.org/index.php?id=download_gb' class='admin' target='_blank' title='Actualiser maintenant'>À la version actuelle</a>";
	$lang['same_version'] = "Vous avez la version la plus récente.<br>Une mise à jour n’est pas nécessaire.";
	$lang['newer_version'] = "Votre version est plus récente que la version stable disponible.<br>Une mise à jour n’est pas nécessaire.";
	$lang['new_version_available'] = "Une nouvelle version est disponible: <a href='http://www.m-gb.org/files/latest/mgb-latest.zip' class='admin' target='_blank' title='Actualiser maintenant'>{LATEST_VERSION}</a>";

// lostpassword.php
	$lang['lostpassword_mail'] = "Votre adresse e-Mail:";
	$lang['get_new_pw'] = "Demander un nouveau mot de passe";
	$lang['lostpassword_success'] = "Votre demande a été traitée. Vous recevrez rapidement un e-Mail avec un<br>lien de confirmation. Cliquez sur ce lien pour activer votre nouveau mot de passe.";
	$lang['lostpassword_success_created'] = "Vos nouvelles données d’accès <br>vous ont été envoyées par e-Mail.";
?>
